@@ -47,23 +47,27 @@ namespace Sass {
     return &lhs && &rhs && *lhs == *rhs;
   }
 
-  void str_rtrim(std::string& s, const std::string& delimiters = " \f\n\r\t\v" )
+  std::string & str_ltrim(std::string & str)
   {
-     s.erase( s.find_last_not_of( delimiters ) + 1 );
+    auto it2 =  std::find_if( str.begin() , str.end() , [](char ch){ return !std::isspace<char>(ch , std::locale::classic() ) ; } );
+    str.erase( str.begin() , it2);
+    return str;
   }
 
-  void str_ltrim(std::string& s,  const std::string& delimiters = " \f\n\r\t\v" )
+  std::string & str_rtrim(std::string & str)
   {
-     s.erase( 0, s.find_first_not_of( delimiters ) );
+    auto it1 =  std::find_if( str.rbegin() , str.rend() , [](char ch){ return !std::isspace<char>(ch , std::locale::classic() ) ; } );
+    str.erase( it1.base() , str.end() );
+    return str;
   }
 
   void String_Constant::rtrim()
   {
-    str_rtrim(value_);
+    value_ = str_rtrim(value_);
   }
   void String_Constant::ltrim()
   {
-    str_ltrim(value_);
+    value_ = str_ltrim(value_);
   }
   void String_Constant::trim()
   {
@@ -97,7 +101,7 @@ namespace Sass {
 
   void Arguments::set_delayed(bool delayed)
   {
-    for (auto __arg = elements().begin(); __arg != elements().end(); ++__arg) { Argument_Obj arg = *(__arg);
+    for (Argument_Obj arg : elements()) {
       if (arg) arg->set_delayed(delayed);
     }
     is_delayed(delayed);
@@ -171,7 +175,7 @@ namespace Sass {
 
   bool Compound_Selector::has_parent_ref()
   {
-    for (auto __s = elements().begin(); __s != elements().end(); ++__s) { Simple_Selector_Obj s = *(__s);
+    for (Simple_Selector_Obj s : *this) {
       if (s && s->has_parent_ref()) return true;
     }
     return false;
@@ -179,7 +183,7 @@ namespace Sass {
 
   bool Compound_Selector::has_real_parent_ref()
   {
-    for (auto __s = elements().begin(); __s != elements().end(); ++__s) { Simple_Selector_Obj s = *(__s);
+    for (Simple_Selector_Obj s : *this) {
       if (s && s->has_real_parent_ref()) return true;
     }
     return false;
@@ -776,7 +780,7 @@ namespace Sass {
 
   bool Compound_Selector::is_superselector_of(Selector_List_Obj rhs, std::string wrapped)
   {
-    for (auto __item = rhs->elements().begin(); __item != rhs->elements().end(); ++__item) { Complex_Selector_Obj item = *(__item);
+    for (Complex_Selector_Obj item : rhs->elements()) {
       if (is_superselector_of(&item, wrapped)) return true;
     }
     return false;
@@ -891,8 +895,8 @@ namespace Sass {
       rset.insert(r->to_string());
     }
 
-    //for (auto __l = lset.begin(); __l != lset.end(); ++__l) { auto l = *(__l); cerr << "l: " << l << endl; }
-    //for (auto __r = rset.begin(); __r != rset.end(); ++__r) { auto r = *(__r); cerr << "r: " << r << endl; }
+    //for (auto l : lset) { cerr << "l: " << l << endl; }
+    //for (auto r : rset) { cerr << "r: " << r << endl; }
 
     if (lset.empty()) return true;
     // return true if rset contains all the elements of lset
@@ -1337,7 +1341,7 @@ namespace Sass {
         retval = this->tails(ctx, &tails);
       }
 
-      for (auto __ss = head->elements().begin(); __ss != head->elements().end(); ++__ss) { Simple_Selector_Obj ss = *(__ss);
+      for (Simple_Selector_Obj ss : head->elements()) {
         if (Wrapped_Selector_Ptr ws = SASS_MEMORY_CAST(Wrapped_Selector, ss)) {
           if (Selector_List_Ptr sl = SASS_MEMORY_CAST(Selector_List, ws->selector())) {
             if (parents) ws->selector(sl->resolve_parent_refs(ctx, pstack, implicit_parent));
@@ -1472,7 +1476,7 @@ namespace Sass {
 
   bool Selector_List::has_parent_ref()
   {
-    for (auto __s = elements().begin(); __s != elements().end(); ++__s) { Complex_Selector_Obj s = *(__s);
+    for (Complex_Selector_Obj s : elements()) {
       if (s && s->has_parent_ref()) return true;
     }
     return false;
@@ -1480,7 +1484,7 @@ namespace Sass {
 
   bool Selector_List::has_real_parent_ref()
   {
-    for (auto __s = elements().begin(); __s != elements().end(); ++__s) { Complex_Selector_Obj s = *(__s);
+    for (Complex_Selector_Obj s : elements()) {
       if (s && s->has_real_parent_ref()) return true;
     }
     return false;
@@ -1581,7 +1585,7 @@ namespace Sass {
   {
 
     Selector_List_Ptr extender = this;
-    for (auto __complex_sel = extendee->elements().begin(); __complex_sel != extendee->elements().end(); ++__complex_sel) { auto complex_sel = *(__complex_sel);
+    for (auto complex_sel : extendee->elements()) {
       Complex_Selector_Obj c = complex_sel;
 
 
@@ -1658,7 +1662,7 @@ namespace Sass {
   Argument_Obj Arguments::get_rest_argument()
   {
     if (this->has_rest_argument()) {
-      for (auto __arg = this->elements().begin(); __arg != this->elements().end(); ++__arg) { Argument_Obj arg = *(__arg);
+      for (Argument_Obj arg : this->elements()) {
         if (arg->is_rest_argument()) {
           return arg;
         }
@@ -1670,7 +1674,7 @@ namespace Sass {
   Argument_Obj Arguments::get_keyword_argument()
   {
     if (this->has_keyword_argument()) {
-      for (auto __arg = this->elements().begin(); __arg != this->elements().end(); ++__arg) { Argument_Obj arg = *(__arg);
+      for (Argument_Obj arg : this->elements()) {
         if (arg->is_keyword_argument()) {
           return arg;
         }
@@ -1838,7 +1842,8 @@ namespace Sass {
     denominator_units_.clear();
 
     // build them by iterating over the exponents
-    for (auto __exp = exponents.begin(); __exp != exponents.end(); ++__exp) { auto exp = *(__exp);
+    for (auto exp : exponents)
+    {
       // maybe there is more effecient way to push
       // the same item multiple times to a vector?
       for(size_t i = 0, S = abs(exp.second); i < S; ++i)
@@ -2049,7 +2054,8 @@ namespace Sass {
     denominator_units_.clear();
 
     // build them by iterating over the exponents
-    for (auto __exp = exponents.begin(); __exp != exponents.end(); ++__exp) { auto exp = *(__exp);
+    for (auto exp : exponents)
+    {
       // maybe there is more effecient way to push
       // the same item multiple times to a vector?
       for(size_t i = 0, S = abs(exp.second); i < S; ++i)
@@ -2239,7 +2245,7 @@ namespace Sass {
   {
     if (Map_Ptr_Const r = dynamic_cast<Map_Ptr_Const>(&rhs)) {
       if (length() != r->length()) return false;
-      for (auto __key = keys().begin(); __key != keys().end(); ++__key) { auto key = *(__key);
+      for (auto key : keys()) {
         Expression_Obj lv = at(key);
         Expression_Obj rv = r->at(key);
         if (!rv || !lv) return false;
@@ -2332,7 +2338,7 @@ namespace Sass {
   List_Obj Map::to_list(Context& ctx, ParserState& pstate) {
     List_Obj ret = SASS_MEMORY_NEW(List, pstate, length(), SASS_COMMA);
 
-    for (auto __key = keys().begin(); __key != keys().end(); ++__key) { auto key = *(__key);
+    for (auto key : keys()) {
       List_Obj l = SASS_MEMORY_NEW(List, pstate, 2);
       l->append(&key);
       l->append(at(key));
