@@ -28,13 +28,13 @@ class LocalOption {
 
 #define ATTACH_OPERATIONS()\
 virtual void perform(Operation<void>* op) { (*op)(this); }\
-virtual AST_Node* perform(Operation<AST_Node*>* op) { return (*op)(this); }\
-virtual Statement* perform(Operation<Statement*>* op) { return (*op)(this); }\
-virtual Expression* perform(Operation<Expression*>* op) { return (*op)(this); }\
-virtual Selector* perform(Operation<Selector*>* op) { return (*op)(this); }\
+virtual AST_Node_Ptr perform(Operation<AST_Node_Ptr>* op) { return (*op)(this); }\
+virtual Statement_Ptr perform(Operation<Statement_Ptr>* op) { return (*op)(this); }\
+virtual Expression_Ptr perform(Operation<Expression_Ptr>* op) { return (*op)(this); }\
+virtual Selector_Ptr perform(Operation<Selector_Ptr>* op) { return (*op)(this); }\
 virtual std::string perform(Operation<std::string>* op) { return (*op)(this); }\
 virtual union Sass_Value* perform(Operation<union Sass_Value*>* op) { return (*op)(this); }\
-virtual Value* perform(Operation<Value*>* op) { return (*op)(this); }
+virtual Value_Ptr perform(Operation<Value_Ptr>* op) { return (*op)(this); }
 
 #define ADD_PROPERTY(type, name)\
 protected:\
