@@ -69,7 +69,7 @@ namespace Sass {
                                               rest->separator(),
                                               true);
               // wrap each item from list as an argument
-              for (auto __item = rest->elements().begin(); __item != rest->elements().end(); ++__item) { Expression_Obj item = *(__item);
+              for (Expression_Obj item : rest->elements()) {
                 if (Argument_Obj arg = SASS_MEMORY_CAST(Argument, item)) {
                   arglist->append(SASS_MEMORY_COPY(arg)); // copy
                 } else {
@@ -94,7 +94,7 @@ namespace Sass {
           List_Ptr arglist = SASS_MEMORY_NEW(List, p->pstate(), 0, SASS_COMMA, true);
           env->local_frame()[p->name()] = arglist;
           Map_Obj argmap = SASS_MEMORY_CAST(Map, a->value());
-          for (auto __key = argmap->keys().begin(); __key != argmap->keys().end(); ++__key) { auto key = *(__key);
+          for (auto key : argmap->keys()) {
             std::string name = unquote(SASS_MEMORY_CAST(String_Constant, key)->value());
             arglist->append(SASS_MEMORY_NEW(Argument,
                                             key->pstate(),
@@ -204,7 +204,7 @@ namespace Sass {
       } else if (a->is_keyword_argument()) {
         Map_Obj argmap = SASS_MEMORY_CAST(Map, a->value());
 
-        for (auto __key = argmap->keys().begin(); __key != argmap->keys().end(); ++__key) { auto key = *(__key);
+        for (auto key : argmap->keys()) {
           std::string name = "$" + unquote(SASS_MEMORY_CAST(String_Constant, key)->value());
 
           if (!param_map.count(name)) {
