@@ -100,7 +100,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     std::cerr << (selector->has_line_feed() ? " [line-feed]": " -");
     std::cerr << std::endl;
 
-    for (auto __i = selector->elements().begin(); __i != selector->elements().end(); ++__i) { const Complex_Selector_Obj& i = *(__i); debug_ast(&i, ind + " ", env); }
+    for(const Complex_Selector_Obj& i : selector->elements()) { debug_ast(&i, ind + " ", env); }
 
 //  } else if (dynamic_cast<Expression_Ptr>(node)) {
 //    Expression_Ptr expression = dynamic_cast<Expression_Ptr>(node);
@@ -162,7 +162,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     std::cerr << (selector->has_line_break() ? " [line-break]": " -");
     std::cerr << (selector->has_line_feed() ? " [line-feed]": " -");
     std::cerr << " <" << prettyprint(selector->pstate().token.ws_before()) << ">" << std::endl;
-    for (auto __i = selector->elements().begin(); __i != selector->elements().end(); ++__i) { const Simple_Selector_Obj& i = *(__i); debug_ast(&i, ind + " ", env); }
+    for(const Simple_Selector_Obj& i : selector->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<Wrapped_Selector_Ptr>(node)) {
     Wrapped_Selector_Ptr selector = dynamic_cast<Wrapped_Selector_Ptr>(node);
     std::cerr << ind << "Wrapped_Selector " << selector;
@@ -262,7 +262,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     << std::endl;
 
     debug_ast(&selector->contents(), ind + " ");
-    // for (auto __i = selector->elements().begin(); __i != selector->elements().end(); ++__i) { auto i = *(__i); debug_ast(i, ind + " ", env); }
+    // for(auto i : selector->elements()) { debug_ast(i, ind + " ", env); }
 
   } else if (dynamic_cast<Selector_Ptr>(node)) {
     Selector_Ptr selector = dynamic_cast<Selector_Ptr>(node);
@@ -289,7 +289,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
       << (block->is_restricted() ? " [is_restricted]": " -")
     << std::endl;
     debug_ast(&block->media_type(), ind + " ");
-    for (auto __i = block->elements().begin(); __i != block->elements().end(); ++__i) { const auto& i = *(__i); debug_ast(&i, ind + " ", env); }
+    for(const auto& i : block->elements()) { debug_ast(&i, ind + " ", env); }
 
   } else if (dynamic_cast<Media_Block_Ptr>(node)) {
     Media_Block_Ptr block = dynamic_cast<Media_Block_Ptr>(node);
@@ -297,7 +297,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     std::cerr << " (" << pstate_source_position(node) << ")";
     std::cerr << " " << block->tabs() << std::endl;
     debug_ast(&block->media_queries(), ind + " =@ ");
-    if (block->block()) for (auto __i = block->block()->elements().begin(); __i != block->block()->elements().end(); ++__i) { const Statement_Obj& i = *(__i); debug_ast(&i, ind + " ", env); }
+    if (block->block()) for(const Statement_Obj& i : block->block()->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<Supports_Block_Ptr>(node)) {
     Supports_Block_Ptr block = dynamic_cast<Supports_Block_Ptr>(node);
     std::cerr << ind << "Supports_Block " << block;
@@ -338,7 +338,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     std::cerr << " (" << pstate_source_position(node) << ")";
     if (root_block->is_root()) std::cerr << " [root]";
     std::cerr << " " << root_block->tabs() << std::endl;
-    for (auto __i = root_block->elements().begin(); __i != root_block->elements().end(); ++__i) { const Statement_Obj& i = *(__i); debug_ast(&i, ind + " ", env); }
+    for(const Statement_Obj& i : root_block->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<Warning_Ptr>(node)) {
     Warning_Ptr block = dynamic_cast<Warning_Ptr>(node);
     std::cerr << ind << "Warning " << block;
@@ -422,7 +422,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     std::cerr << " (" << pstate_source_position(node) << ")";
     std::cerr << " " << has_block->tabs() << std::endl;
     if (has_block->name()) debug_ast(&has_block->name(), ind + "@");
-    if (has_block->block()) for (auto __i = has_block->block()->elements().begin(); __i != has_block->block()->elements().end(); ++__i) { const Statement_Obj& i = *(__i); debug_ast(&i, ind + " ", env); }
+    if (has_block->block()) for(const Statement_Obj& i : has_block->block()->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<Directive_Ptr>(node)) {
     Directive_Ptr block = dynamic_cast<Directive_Ptr>(node);
     std::cerr << ind << "Directive " << block;
@@ -430,25 +430,25 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     std::cerr << " [" << block->keyword() << "] " << block->tabs() << std::endl;
     debug_ast(&block->selector(), ind + "~", env);
     debug_ast(&block->value(), ind + "+", env);
-    if (block->block()) for (auto __i = block->block()->elements().begin(); __i != block->block()->elements().end(); ++__i) { const Statement_Obj& i = *(__i); debug_ast(&i, ind + " ", env); }
+    if (block->block()) for(const Statement_Obj& i : block->block()->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<Each_Ptr>(node)) {
     Each_Ptr block = dynamic_cast<Each_Ptr>(node);
     std::cerr << ind << "Each " << block;
     std::cerr << " (" << pstate_source_position(node) << ")";
     std::cerr << " " << block->tabs() << std::endl;
-    if (block->block()) for (auto __i = block->block()->elements().begin(); __i != block->block()->elements().end(); ++__i) { const Statement_Obj& i = *(__i); debug_ast(&i, ind + " ", env); }
+    if (block->block()) for(const Statement_Obj& i : block->block()->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<For_Ptr>(node)) {
     For_Ptr block = dynamic_cast<For_Ptr>(node);
     std::cerr << ind << "For " << block;
     std::cerr << " (" << pstate_source_position(node) << ")";
     std::cerr << " " << block->tabs() << std::endl;
-    if (block->block()) for (auto __i = block->block()->elements().begin(); __i != block->block()->elements().end(); ++__i) { const Statement_Obj& i = *(__i); debug_ast(&i, ind + " ", env); }
+    if (block->block()) for(const Statement_Obj& i : block->block()->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<While_Ptr>(node)) {
     While_Ptr block = dynamic_cast<While_Ptr>(node);
     std::cerr << ind << "While " << block;
     std::cerr << " (" << pstate_source_position(node) << ")";
     std::cerr << " " << block->tabs() << std::endl;
-    if (block->block()) for (auto __i = block->block()->elements().begin(); __i != block->block()->elements().end(); ++__i) { const Statement_Obj& i = *(__i); debug_ast(&i, ind + " ", env); }
+    if (block->block()) for(const Statement_Obj& i : block->block()->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<Definition_Ptr>(node)) {
     Definition_Ptr block = dynamic_cast<Definition_Ptr>(node);
     std::cerr << ind << "Definition " << block;
@@ -485,7 +485,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     std::cerr << " (" << pstate_source_position(node) << ")";
     std::cerr << (block->is_invisible() ? " [INVISIBLE]" : "");
     std::cerr << " [indent: " << block->tabs() << "]" << std::endl;
-    for (auto __i = block->elements().begin(); __i != block->elements().end(); ++__i) { const Statement_Obj& i = *(__i); debug_ast(&i, ind + " ", env); }
+    for(const Statement_Obj& i : block->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<Textual_Ptr>(node)) {
     Textual_Ptr expression = dynamic_cast<Textual_Ptr>(node);
     std::cerr << ind << "Textual " << expression;
@@ -533,7 +533,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     if (expression->has_rest_argument()) std::cerr << " [has_rest_argument]";
     if (expression->has_keyword_argument()) std::cerr << " [has_keyword_argument]";
     std::cerr << std::endl;
-    for (auto __i = expression->elements().begin(); __i != expression->elements().end(); ++__i) { const Argument_Obj& i = *(__i); debug_ast(&i, ind + " ", env); }
+    for(const Argument_Obj& i : expression->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<Argument_Ptr>(node)) {
     Argument_Ptr expression = dynamic_cast<Argument_Ptr>(node);
     std::cerr << ind << "Argument " << expression;
@@ -550,7 +550,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     std::cerr << " [has_optional: " << expression->has_optional_parameters() << "] ";
     std::cerr << " [has_rest: " << expression->has_rest_parameter() << "] ";
     std::cerr << std::endl;
-    for (auto __i = expression->elements().begin(); __i != expression->elements().end(); ++__i) { const Parameter_Obj& i = *(__i); debug_ast(&i, ind + " ", env); }
+    for(const Parameter_Obj& i : expression->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<Parameter_Ptr>(node)) {
     Parameter_Ptr expression = dynamic_cast<Parameter_Ptr>(node);
     std::cerr << ind << "Parameter " << expression;
@@ -585,7 +585,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     std::cerr << " [interpolant: " << expression->is_interpolant() << "] ";
     std::cerr << " (" << pstate_source_position(node) << ")";
     std::cerr << " [Hashed]" << std::endl;
-    for (auto __i = expression->elements().begin(); __i != expression->elements().end(); ++__i) { const auto& i = *(__i);
+    for (const auto& i : expression->elements()) {
       debug_ast(&i.first, ind + " key: ");
       debug_ast(&i.second, ind + " val: ");
     }
@@ -601,7 +601,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
       " [arglist: " << expression->is_arglist() << "] " <<
       " [hash: " << expression->hash() << "] " <<
       std::endl;
-    for (auto __i = expression->elements().begin(); __i != expression->elements().end(); ++__i) { const auto& i = *(__i); debug_ast(&i, ind + " ", env); }
+    for(const auto& i : expression->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<Content_Ptr>(node)) {
     Content_Ptr expression = dynamic_cast<Content_Ptr>(node);
     std::cerr << ind << "Content " << expression;
@@ -668,7 +668,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     if (expression->is_left_interpolant()) std::cerr << " [left interpolant] ";
     if (expression->is_right_interpolant()) std::cerr << " [right interpolant] ";
     std::cerr << " <" << prettyprint(expression->pstate().token.ws_before()) << ">" << std::endl;
-    for (auto __i = expression->elements().begin(); __i != expression->elements().end(); ++__i) { const auto& i = *(__i); debug_ast(&i, ind + " ", env); }
+    for(const auto& i : expression->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<String_Ptr>(node)) {
     String_Ptr expression = dynamic_cast<String_Ptr>(node);
     std::cerr << ind << "String " << expression;
@@ -701,7 +701,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     std::cerr << ind << "Has_Block " << has_block;
     std::cerr << " (" << pstate_source_position(node) << ")";
     std::cerr << " " << has_block->tabs() << std::endl;
-    if (has_block->block()) for (auto __i = has_block->block()->elements().begin(); __i != has_block->block()->elements().end(); ++__i) { const Statement_Obj& i = *(__i); debug_ast(&i, ind + " ", env); }
+    if (has_block->block()) for(const Statement_Obj& i : has_block->block()->elements()) { debug_ast(&i, ind + " ", env); }
   } else if (dynamic_cast<Statement_Ptr>(node)) {
     Statement_Ptr statement = dynamic_cast<Statement_Ptr>(node);
     std::cerr << ind << "Statement " << statement;
@@ -742,7 +742,7 @@ inline void debug_node(Node* node, std::string ind = "")
     std::cerr << node << " ";
     if (node->got_line_feed) std::cerr << "[LF] ";
     std::cerr << std::endl;
-    for (auto __n = (*node->collection()).begin(); __n != (*node->collection()).end(); ++__n) { auto n = *(__n);
+    for(auto n : (*node->collection())) {
       debug_node(&n, ind + "  ");
     }
   } else if (node->isNil()) {
