@@ -111,10 +111,10 @@ namespace Sass {
     // do some special checks for the base level rules
     if (r->is_root()) {
       if (Selector_List_Ptr selector_list = SASS_MEMORY_CAST(Selector_List, r->selector())) {
-        for (auto __complex_selector = selector_list->elements().begin(); __complex_selector != selector_list->elements().end(); ++__complex_selector) { Complex_Selector_Obj complex_selector = *(__complex_selector);
+        for (Complex_Selector_Obj complex_selector : selector_list->elements()) {
           Complex_Selector_Ptr tail = &complex_selector;
           while (tail) {
-            if (tail->head()) for (auto __header = tail->head()->elements().begin(); __header != tail->head()->elements().end(); ++__header) { Simple_Selector_Obj header = *(__header);
+            if (tail->head()) for (Simple_Selector_Obj header : tail->head()->elements()) {
               if (SASS_MEMORY_CAST(Parent_Selector, header) == NULL) continue; // skip all others
               std::string sel_str(complex_selector->to_string(ctx.c_options));
               error("Base-level rules cannot contain the parent-selector-referencing character '&'.", header->pstate(), backtrace());
@@ -494,7 +494,7 @@ namespace Sass {
     Block_Ptr body = &e->block();
 
     if (map) {
-      for (auto __key = map->keys().begin(); __key != map->keys().end(); ++__key) { auto key = *(__key);
+      for (auto key : map->keys()) {
         Expression_Obj k = key->perform(&eval);
         Expression_Obj v = map->at(key)->perform(&eval);
 
@@ -577,10 +577,10 @@ namespace Sass {
   void Expand::expand_selector_list(Selector_Obj s, Selector_List_Obj extender) {
 
     if (Selector_List_Obj sl = SASS_MEMORY_CAST(Selector_List, s)) {
-      for (auto __complex_selector = sl->elements().begin(); __complex_selector != sl->elements().end(); ++__complex_selector) { Complex_Selector_Obj complex_selector = *(__complex_selector);
+      for (Complex_Selector_Obj complex_selector : sl->elements()) {
         Complex_Selector_Obj tail = complex_selector;
         while (tail) {
-          if (tail->head()) for (auto __header = tail->head()->elements().begin(); __header != tail->head()->elements().end(); ++__header) { Simple_Selector_Obj header = *(__header);
+          if (tail->head()) for (Simple_Selector_Obj header : tail->head()->elements()) {
             if (SASS_MEMORY_CAST(Parent_Selector, header) == NULL) continue; // skip all others
             std::string sel_str(complex_selector->to_string(ctx.c_options));
             error("Can't extend " + sel_str + ": can't extend parent selectors", header->pstate(), backtrace());
@@ -593,7 +593,7 @@ namespace Sass {
 
     Selector_List_Obj contextualized = SASS_MEMORY_CAST_PTR(Selector_List, s->perform(&eval));
     if (contextualized == false) return;
-    for (auto __complex_sel = contextualized->elements().begin(); __complex_sel != contextualized->elements().end(); ++__complex_sel) { auto complex_sel = *(__complex_sel);
+    for (auto complex_sel : contextualized->elements()) {
       Complex_Selector_Obj c = complex_sel;
       if (!c->head() || c->tail()) {
         std::string sel_str(contextualized->to_string(ctx.c_options));
@@ -645,7 +645,7 @@ namespace Sass {
       }
       // abort on invalid selector
       if (sl.isNull()) return NULL;
-      for (auto __cs = sl->elements().begin(); __cs != sl->elements().end(); ++__cs) { Complex_Selector_Obj cs = *(__cs);
+      for (Complex_Selector_Obj cs : sl->elements()) {
         if (!cs.isNull() && !cs->head().isNull()) {
           cs->head()->media_block(media_block_stack.back());
         }
@@ -728,7 +728,7 @@ namespace Sass {
 
 
     block_stack.push_back(&trace_block);
-    for (auto __bb = body->elements().begin(); __bb != body->elements().end(); ++__bb) { auto bb = *(__bb);
+    for (auto bb : body->elements()) {
       Statement_Obj ith = bb->perform(this);
       if (ith) trace->block()->append(ith);
     }
