@@ -193,7 +193,7 @@ namespace Sass {
     }
     bool first = true;
     std::cerr << "[";
-    for (auto __pair = collection.begin(); __pair != collection.end(); ++__pair) { SelsNewSeqPair& pair = *(__pair);
+    for(SelsNewSeqPair& pair : collection) {
       if (first) {
         first = false;
       } else {
@@ -1718,7 +1718,7 @@ namespace Sass {
 
       if (pHead) {
         SubsetMapEntries entries = subset_map.get_v(pHead);
-        for (auto __ext = entries.begin(); __ext != entries.end(); ++__ext) { ExtensionPair ext = *(__ext);
+        for (ExtensionPair ext : entries) {
           // check if both selectors have the same media block parent
           // if (ext.first->media_block() == pComplexSelector->media_block()) continue;
           if (ext.second->media_block() == 0) continue;
@@ -1939,7 +1939,7 @@ namespace Sass {
     pNewSelectors = remove_placeholders.remove_placeholders(&pNewSelectors);
 
     // unwrap all wrapped selectors with inner lists
-    for (auto __cur = pNewSelectors->elements().begin(); __cur != pNewSelectors->elements().end(); ++__cur) { Complex_Selector_Obj cur = *(__cur);
+    for (Complex_Selector_Obj cur : pNewSelectors->elements()) {
       // process tails
       while (cur) {
         // process header
@@ -1948,7 +1948,7 @@ namespace Sass {
           recseen.insert(*cur->head());
           // create a copy since we add multiple items if stuff get unwrapped
           Compound_Selector_Obj cpy_head = SASS_MEMORY_NEW(Compound_Selector, cur->pstate());
-          for (auto __hs = cur->head()->elements().begin(); __hs != cur->head()->elements().end(); ++__hs) { Simple_Selector_Obj hs = *(__hs);
+          for (Simple_Selector_Obj hs : *cur->head()) {
             if (Wrapped_Selector_Obj ws = SASS_MEMORY_CAST(Wrapped_Selector, hs)) {
               ws->selector(SASS_MEMORY_CLONE(ws->selector()));
               if (Selector_List_Obj sl = SASS_MEMORY_CAST(Selector_List, ws->selector())) {
@@ -2079,8 +2079,7 @@ namespace Sass {
     // we set `extended` flag on extended selectors
     if (b->is_root()) {
       // debug_subset_map(subset_map);
-      auto values = subset_map.values();
-      for (auto __it = values.begin(); __it != values.end(); ++__it) { auto it = *(__it);
+      for(auto const &it : subset_map.values()) {
         Complex_Selector_Ptr sel = it.first ? &it.first->first() : NULL;
         Compound_Selector_Ptr ext = it.second ? &it.second : NULL;
         if (ext && (ext->extended() || ext->is_optional())) continue;
