@@ -308,7 +308,7 @@ namespace Sass {
     do {
       while (lex< block_comment >());
       if (lex< quoted_string >()) {
-        to_import.push_back(std::pair<std::string,Function_Call_Obj>(std::string(lexed), (Function_Call*) NULL));
+        to_import.push_back(std::pair<std::string,Function_Call_Obj>(std::string(lexed), 0));
       }
       else if (lex< uri_prefix >()) {
         Arguments_Obj args = SASS_MEMORY_NEW(Arguments, pstate);
@@ -343,7 +343,7 @@ namespace Sass {
       imp->import_queries(import_queries);
     }
 
-    for (auto __location = to_import.begin(); __location != to_import.end(); ++__location) { auto location = *(__location);
+    for(auto location : to_import) {
       if (location.second) {
         imp->urls().push_back(&location.second);
       } else if (!ctx.call_importers(unquote(location.first), path, pstate, &imp)) {
