@@ -89,7 +89,7 @@ namespace Sass {
   {
     std::string out("");
     bool esc = false;
-    for (auto __i = str.begin(); __i != str.end(); ++__i) { auto i = *(__i);
+    for (auto i : str) {
       if (i == '\\') {
         esc = ! esc;
       } else if (esc && i == '\r') {
@@ -116,7 +116,7 @@ namespace Sass {
   {
     std::string out("");
     bool esc = false;
-    for (auto __i = str.begin(); __i != str.end(); ++__i) { auto i = *(__i);
+    for (auto i : str) {
       if (i == '\\' && !esc) {
         out += '\\';
         out += '\\';
@@ -157,7 +157,7 @@ namespace Sass {
   {
     std::string out("");
     bool lf = false;
-    for (auto __i = str.begin(); __i != str.end(); ++__i) { auto i = *(__i);
+    for (auto i : str) {
       if (i == '\n') {
         out += ' ';
         lf = true;
@@ -175,7 +175,7 @@ namespace Sass {
     size_t has = 0;
     char prev = 0;
     bool clean = false;
-    for (auto __i = text.begin(); __i != text.end(); ++__i) { auto i = *(__i);
+    for (auto i : text) {
       if (clean) {
         if (i == '\n') { has = 0; }
         else if (i == '\r') { has = 0; }
